summaryrefslogtreecommitdiff
path: root/tool/lib
diff options
context:
space:
mode:
authorTakashi Kokubun <takashikkbn@gmail.com>2023-03-06 23:15:30 -0800
committerTakashi Kokubun <takashikkbn@gmail.com>2023-03-06 23:44:01 -0800
commit2e875549a934fa04b7939810fa0d8a2762702aaa (patch)
tree116b99056f810d48359ac6fa6a3b06e9ddc65c05 /tool/lib
parenteaccdc1941304d6273397b21c25213174d892185 (diff)
downloadruby-2e875549a934fa04b7939810fa0d8a2762702aaa.tar.gz
s/MJIT/RJIT/
Diffstat (limited to 'tool/lib')
-rw-r--r--tool/lib/core_assertions.rb4
-rw-r--r--tool/lib/test/unit.rb10
2 files changed, 7 insertions, 7 deletions
diff --git a/tool/lib/test/unit.rb b/tool/lib/test/unit.rb
index 0fa7b4c5cd..fe5c17887c 100644
--- a/tool/lib/test/unit.rb
+++ b/tool/lib/test/unit.rb
@@ -89,16 +89,16 @@ module Test
end
end
- module MJITFirst
+ module RJITFirst
def group(list)
- # MJIT first
+ # RJIT first
mjit, others = list.partition {|e| /test_mjit/ =~ e}
mjit + others
end
end
class Alpha < NoSort
- include MJITFirst
+ include RJITFirst
def sort_by_name(list)
list.sort_by(&:name)
@@ -112,7 +112,7 @@ module Test
# shuffle test suites based on CRC32 of their names
Shuffle = Struct.new(:seed, :salt) do
- include MJITFirst
+ include RJITFirst
def initialize(seed)
self.class::CRC_TBL ||= (0..255).map {|i|
@@ -1589,7 +1589,7 @@ module Test
puts if @verbose
$stdout.flush
- unless defined?(RubyVM::MJIT) && RubyVM::MJIT.enabled? # compiler process is wrongly considered as leak
+ unless defined?(RubyVM::RJIT) && RubyVM::RJIT.enabled? # compiler process is wrongly considered as leak
leakchecker.check("#{inst.class}\##{inst.__name__}")
end
diff --git a/tool/lib/core_assertions.rb b/tool/lib/core_assertions.rb
index fdae050bb5..c646281549 100644
--- a/tool/lib/core_assertions.rb
+++ b/tool/lib/core_assertions.rb
@@ -111,8 +111,8 @@ module Test
end
def assert_no_memory_leak(args, prepare, code, message=nil, limit: 2.0, rss: false, **opt)
- # TODO: consider choosing some appropriate limit for MJIT and stop skipping this once it does not randomly fail
- pend 'assert_no_memory_leak may consider MJIT memory usage as leak' if defined?(RubyVM::MJIT) && RubyVM::MJIT.enabled?
+ # TODO: consider choosing some appropriate limit for RJIT and stop skipping this once it does not randomly fail
+ pend 'assert_no_memory_leak may consider RJIT memory usage as leak' if defined?(RubyVM::RJIT) && RubyVM::RJIT.enabled?
require_relative 'memory_status'
raise Test::Unit::PendedError, "unsupported platform" unless defined?(Memory::Status)